@@ -6,15 +6,15 @@ use warnings;
 
 =head1 NAME
 
-ACME::YAPC::NA::2012 - The great new ACME::YAPC::NA::2012!
+ACME::YAPC::NA::2012 - Random test module for YAPC::NA tutorial
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.02_01';
 
 
 =head1 SYNOPSIS
